@@ -1,4 +1,4 @@
-__version__="3.1.2"
+__version__ = "3.3.0"
 
 
 import os
@@ -9,8 +9,5 @@ from bnlp.tokenizer.basic import BasicTokenizer
 from bnlp.tokenizer.sentencepiece import SentencepieceTokenizer
 from bnlp.embedding.word2vec import BengaliWord2Vec
 from bnlp.embedding.glove import BengaliGlove
-
-
-
-
-
+from bnlp.embedding.doc2vec import BengaliDoc2vec
+from bnlp.cleantext.clean import CleanText
\ No newline at end of file
